==> haskell-microstache-1.0.2.3-181-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microstache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microstache
version:              1.0.2.3
visibility:           public
id:                   microstache-1.0.2.3-7vJu460oMCfoj0RJdQJFE
key:                  microstache-1.0.2.3-7vJu460oMCfoj0RJdQJFE
license:              BSD-3-Clause
maintainer:           Oleg Grenrus<oleg.grenrus@iki.fi>
author:
    Mark Karpov <markkarpov@openmailbox.org>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/microstache
synopsis:             Mustache templates for Haskell
description:
    Mustache templates for Haskell.

    Based on @stache@ library, which uses @megaparsec@.
    This library uses @parsec@, thus the name: @microstache@.

category:             Text
abi:                  d889668bd7adfaf3774b9c01de8fc2d4
exposed:              True
exposed-modules:
    Text.Microstache Text.Microstache.Compile Text.Microstache.Parser
    Text.Microstache.Render Text.Microstache.Type

import-dirs:          /usr/lib/ghc-9.4.8/site-local/microstache-1.0.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/microstache-1.0.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/microstache-1.0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microstache
hs-libraries:         HSmicrostache-1.0.2.3-7vJu460oMCfoj0RJdQJFE
depends:
    aeson-2.1.2.1-CM1TyKExMgH6p2KQqrdDHD base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2 parsec-3.1.16.1
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-FLM1pZb3BI5FpyNo5sVXNv
    vector-0.13.2.0-LmFi28PTaN7DJJszRwFTiC

haddock-interfaces:   /usr/share/doc/haskell-microstache/html/microstache.haddock
haddock-html:         /usr/share/doc/haskell-microstache/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microstache-1.0.2.3-182-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microstache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microstache
version:              1.0.2.3
visibility:           public
id:                   microstache-1.0.2.3-4TLBCRYlOwZEed3cSNbBGO
key:                  microstache-1.0.2.3-4TLBCRYlOwZEed3cSNbBGO
license:              BSD-3-Clause
maintainer:           Oleg Grenrus<oleg.grenrus@iki.fi>
author:
    Mark Karpov <markkarpov@openmailbox.org>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/microstache
synopsis:             Mustache templates for Haskell
description:
    Mustache templates for Haskell.

    Based on @stache@ library, which uses @megaparsec@.
    This library uses @parsec@, thus the name: @microstache@.

category:             Text
abi:                  39701db782c67424620693a077a58776
exposed:              True
exposed-modules:
    Text.Microstache Text.Microstache.Compile Text.Microstache.Parser
    Text.Microstache.Render Text.Microstache.Type

import-dirs:          /usr/lib/ghc-9.4.8/site-local/microstache-1.0.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/microstache-1.0.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/microstache-1.0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microstache
hs-libraries:         HSmicrostache-1.0.2.3-4TLBCRYlOwZEed3cSNbBGO
depends:
    aeson-2.1.2.1-F8ZePgr6g4xL6kF4wsQx0x base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2 parsec-3.1.16.1
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-I3GOf8berWn8tol6ImoSEe
    vector-0.13.2.0-7bZcynEBhMGLMgNICkU4Wg

haddock-interfaces:   /usr/share/doc/haskell-microstache/html/microstache.haddock
haddock-html:         /usr/share/doc/haskell-microstache/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
